@@ -24,6 +24,10 @@
 #include <sys/stat.h>
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <glib/gstdio.h>
+#include <fcntl.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 
 #include <gdk/gdkkeysyms.h>
 
@@ -60,6 +64,8 @@
 
 #include "expand.h"
 
+#include "selection.h"
+
 
 /**
  * Open the selected file.
@@ -74,17 +80,32 @@ void popup_open_file_cb()
 
    // several files in selection?
 
-   // We can only open files
+   GList *list = get_list_of_marked_files();
 
-   if (!clicked_node.valid || clicked_node.type != ITEMTYPE_FILE) {
-      goto EXITPOINT;
+   if (list != NULL) {
+      for (GList *temp = list; temp != NULL; temp = temp -> next) {
+         ClickedNode *curr = temp->data;
+
+         if (curr) {
+
+            // We can only open files
+            if (!curr->valid || curr->type != ITEMTYPE_FILE) {
+               goto EXITPOINT;
+            }
+
+            gchar *fixed = fix_path((gchar*)get_project_directory(), curr->name);
+
+            if (!open_filename(curr->name, (gchar*)(get_project_directory()), &err)) {
+               goto EXITPOINT;
+            }
+
+            add_file_to_recent (fixed, NULL);
+         }
+      }
+
+      g_list_free_full (list, (GDestroyNotify) g_free);
    }
 
-   if (!open_filename(clicked_node.name, (gchar*)(get_project_directory()), &err)) {
-      goto EXITPOINT;
-   }
-
-   add_file_to_recent(clicked_node.name, NULL);
 
 
 EXITPOINT:
@@ -613,6 +634,7 @@ void refresh_folder_with_iter(GtkTreeIter *iter)
 
 }
 
+
 /**
  *
  */
@@ -623,8 +645,232 @@ void refresh_folder(ClickedNode *inNode)
    }
    
    GtkTreeIter iter = inNode->iter;
-   
+
    if (tree_iter_is_valid(&iter)) {
       refresh_folder_with_iter(&iter);
    }
 }
+
+
+gchar *entry_text;
+GtkWidget *entry;
+GtkWidget *request_filename_dialog;
+
+
+static void text_entry_text_changed (void)
+{
+   if (entry != NULL) {
+      entry_text = (gchar*)gtk_entry_get_text (GTK_ENTRY (entry));
+   }
+}
+
+
+static void text_entry_activate (void)
+{
+   printf("activate\n");
+   // GtkWidget *dialog = (GtkWidget *)data;
+
+   gtk_dialog_response( GTK_DIALOG(request_filename_dialog), GTK_RESPONSE_ACCEPT);
+}
+
+
+/**
+ *
+ */
+int
+get_requested_file_name (gchar **string_result)
+{
+   GtkWidget *content_area;
+
+   GtkWidget *label;
+
+   GtkDialogFlags flags;
+
+   GtkWidget *grid;
+
+   // gchar *string_result = NULL;
+   int int_result = 0;
+
+   GtkWindow *main_window = get_main_window();
+
+   // Create the widgets
+   flags = GTK_DIALOG_DESTROY_WITH_PARENT;
+   request_filename_dialog = gtk_dialog_new_with_buttons ("Message",
+                                       main_window,
+                                       flags,
+                                       _("_OK"),
+                                       GTK_RESPONSE_ACCEPT,
+                                       _("_Cancel"),
+                                       GTK_RESPONSE_REJECT,
+                                       NULL);
+   content_area = gtk_dialog_get_content_area (GTK_DIALOG (request_filename_dialog));
+   label = gtk_label_new ("File name:");
+
+   // Ensure that the dialog box is destroyed when the user responds
+
+   // Add the label, and show everything we’ve added
+
+   grid = gtk_grid_new();
+
+   gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
+
+   entry = gtk_entry_new ();
+
+   gtk_widget_show (GTK_WIDGET (entry));
+
+   gtk_entry_set_max_length (GTK_ENTRY (entry), 0);
+
+   g_signal_connect (GTK_EDITABLE (entry), "changed", G_CALLBACK (text_entry_text_changed), NULL);
+   g_signal_connect (GTK_ENTRY (entry), "activate", G_CALLBACK (text_entry_activate), NULL);
+
+   gtk_grid_attach (GTK_GRID (grid), entry, 1, 0, 1, 1);
+
+   gtk_widget_show (GTK_WIDGET (grid));
+   gtk_widget_show (GTK_WIDGET (label));
+
+   gtk_container_add (GTK_CONTAINER (content_area), grid);
+
+   gtk_dialog_set_default_response (GTK_DIALOG (request_filename_dialog), GTK_RESPONSE_ACCEPT);
+
+   gint result = gtk_dialog_run (GTK_DIALOG (request_filename_dialog));
+
+   switch (result) {
+   case GTK_RESPONSE_ACCEPT:
+      int_result = 1;
+      if (string_result != NULL) {
+         (*string_result) = (gchar *)g_strdup_printf("%s", entry_text);
+      }
+      break;
+   case GTK_RESPONSE_REJECT:
+      int_result = 0;
+      break;
+   default:
+      int_result = 0;
+   };
+
+   gtk_widget_destroy (GTK_WIDGET (request_filename_dialog));
+
+   return int_result;
+}
+
+
+/**
+ *
+ */
+int warning_dialog(const char *fmt, ...)
+{
+   GtkWidget *warning_dialog;
+   GtkWindow *main_window = get_main_window();
+
+   gchar *formatted_string;
+
+   va_list argptr;
+   va_start(argptr, fmt);
+   formatted_string = g_strdup_vprintf(fmt, argptr);
+   va_end(argptr);
+
+   warning_dialog = gtk_message_dialog_new (main_window,
+                                            GTK_DIALOG_DESTROY_WITH_PARENT,
+                                            GTK_MESSAGE_ERROR,
+                                            GTK_BUTTONS_CLOSE,
+                                            "%s", formatted_string
+                                            );
+   gtk_dialog_run (GTK_DIALOG (warning_dialog));
+   gtk_widget_destroy (warning_dialog);
+   
+   g_free(formatted_string);
+
+   return 0;
+}
+
+
+/**
+ *
+ */
+void create_new_file_cb()
+{
+   GtkTreeModel *tree_model = gtk_tree_view_get_model(GTK_TREE_VIEW(projectTreeView));
+   gchar *full_file_name = NULL;
+
+   // We can only open files
+   if (!clicked_node.valid || clicked_node.type != ITEMTYPE_GROUP) {
+      goto EXITPOINT;
+   }
+
+   // add_file_to_recent(clicked_node.name, NULL);
+
+   // Open the folder if it isn't open already
+
+   GtkTreeIter *iter = gtk_tree_iter_copy(&(clicked_node.iter));
+
+   if (tree_iter_is_valid(iter)) {
+
+      printf("Clicked node: %s\n", clicked_node.name);
+
+      GtkTreePath *path;
+      path = gtk_tree_model_get_path(tree_model, iter);
+      expand_tree_row(path, FALSE);
+
+      gchar *filename = NULL;
+
+      gchar *folder = clicked_node.name;
+
+      int result = get_requested_file_name(&filename);
+
+      if (result != 0) {
+
+         printf("File name: %s\n", filename);
+
+         // build filename including folder
+
+         // check if the file already exists in the file system
+
+         full_file_name = g_build_filename(folder, filename, NULL);
+
+         if (g_file_test(full_file_name, G_FILE_TEST_EXISTS)) {
+            warning_dialog("The file '%s' does already exist!", filename);
+
+            goto EXITPOINT;
+
+         }
+
+         mode_t mode = S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH;
+
+         int create_result = g_creat (full_file_name, mode);
+         if (create_result == -1) {
+            warning_dialog ("The file '%s' couldn't be created!", filename);
+
+            goto EXITPOINT;
+         }
+
+         GtkTreeIter newIter;
+
+         gtk_tree_model_iter_parent(tree_model, &newIter, iter);
+
+         refresh_folder_with_iter(&newIter);
+
+         GtkTreeIter temp;
+         GtkTreeIter *result_iter = NULL;
+
+         if (gtk_tree_model_get_iter_first (tree_model, &temp)) {
+            printf ("before find_element_with_path\n");
+            result_iter = find_element_with_path (&temp, full_file_name);
+         }
+
+         if (result_iter != NULL) {
+            GtkTreePath *cursor_path = gtk_tree_model_get_path(tree_model, result_iter);
+
+            gtk_tree_view_set_cursor(GTK_TREE_VIEW(projectTreeView), cursor_path, NULL, TRUE);
+         }
+      }
+      gtk_tree_path_free(path);
+   }
+
+EXITPOINT:
+
+   if (full_file_name != NULL) {
+      g_free(full_file_name);
+   }
+
+   return;
+}
