@@ -16,8 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with SciteProj.
- * If not, see <http://www.gnu.org/licenses/>.
+ * along with SciteProj.  If not, see <http://www.gnu.org/licenses/>.
  *
  */
 #ifndef __HEADER_TREE_MANIPULATION_
@@ -88,7 +87,6 @@ void done_treestore();
 
 // Get the project file directory
 const gchar* get_project_directory();
-gchar* get_project_filepath();
 
 gboolean tree_iter_is_valid(GtkTreeIter *iter);
 
@@ -139,6 +137,8 @@ void sort_children(GtkTreeIter *node, GError **err, StringCompareFunction compar
 
 gboolean add_tree_folderlist(GtkTreeIter *iter, GSList *folder_list, gchar *folder_path);
 
+GtkTreeIter *find_element_with_path (GtkTreeIter *start_iter, gchar *path_to_find);
+
 #ifdef _DEBUG
 void print_node(GtkTreeIter *iter);
 #endif
